@@ -572,7 +572,7 @@ byteswap(PyObject *module, PyObject *args)
 }
 
 PyDoc_STRVAR(byteswap_doc,
-"byteswap(a, /, n=<buffer size>)\n\
+"byteswap(a, n=<buffer size>, /)\n\
 \n\
 Reverse every `n` consecutive bytes of `a` in-place.\n\
 By default, all bytes are reversed.  Note that `n` is not limited to 2, 4\n\
@@ -869,14 +869,18 @@ digit_to_int(int m, char c)
 static int
 base_to_length(int n)
 {
-    int m;
+    int m = 0;
 
-    for (m = 1; m < 7; m++) {
-        if (n == (1 << m))
-            return m;
+    if (!n || n & (n - 1)) {
+        PyErr_SetString(PyExc_ValueError, "base must be a power of 2");
+        return -1;
     }
-    PyErr_Format(PyExc_ValueError,
-                 "base must be 2, 4, 8, 16, 32 or 64, not %d", n);
+    while (n >>= 1)
+        m++;
+    if (1 <= m && m <= 6)
+        return m;
+
+    PyErr_SetString(PyExc_ValueError, "base must be 2, 4, 8, 16, 32 or 64");
     return -1;
 }
 
@@ -1731,7 +1735,7 @@ sc_decode(PyObject *module, PyObject *obj)
 }
 
 PyDoc_STRVAR(sc_decode_doc,
-"sc_decode(stream) -> bitarray\n\
+"sc_decode(stream, /) -> bitarray\n\
 \n\
 Decompress binary stream (an integer iterator, or bytes-like object) of a\n\
 sparse compressed (`sc`) bitarray, and return the decoded  bitarray.\n\
@@ -2224,14 +2228,9 @@ static PyModuleDef moduledef = {
 PyMODINIT_FUNC
 PyInit__util(void)
 {
-    PyObject *m, *bitarray_module;
+    PyObject *m;
 
-    bitarray_module = PyImport_ImportModule("bitarray");
-    if (bitarray_module == NULL)
-        return NULL;
-    bitarray_type = (PyTypeObject *) PyObject_GetAttrString(bitarray_module,
-                                                            "bitarray");
-    Py_DECREF(bitarray_module);
+    bitarray_type = (PyTypeObject *) bitarray_module_attr("bitarray");
     if (bitarray_type == NULL)
         return NULL;
 
