@@ -4,7 +4,7 @@
 
    Author: Ilan Schnell
 */
-#define BITARRAY_VERSION  "3.5.0"
+#define BITARRAY_VERSION  "3.7.0"
 
 #ifdef STDC_HEADERS
 #  include <stddef.h>
@@ -225,6 +225,35 @@ swap_bytes(char *p, Py_ssize_t n)
     }
 }
 
+/* write 256 characters into table for given kernel operation */
+static inline void
+setup_table(char *table, char kop)
+{
+    int k;
+    for (k = 0; k < 256; k++) {
+        char t = 0, j;
+        for (j = 0; j < 8; j++) {
+            if (k & 1 << j)
+                /* j are the indices of active bits in k (little endian) */
+                switch (kop) {
+                case 'a': t += j;        break;  /* add active indices */
+                case 'A': t += 7 - j;    break;  /* 'a' for big endian */
+                case 's': t += j * j;    /* add squares of active indices */
+                    break;
+                case 'S': t += (7-j) * (7-j);    /* 's' for big endian */
+                    break;
+                case 'x': t ^= j;        break;  /* xor active indices */
+                case 'X': t ^= 7 - j;    break;  /* 'x' for big endian */
+                case 'c': t++;           break;  /* bit count */
+                case 'p': t ^= 1;        break;  /* parity */
+                case 'r': t |= 128 >> j; break;  /* reverse bits */
+                default: Py_UNREACHABLE();
+                }
+        }
+        table[k] = t;
+    }
+}
+
 /* Return distance [0..3] to next aligned pointer.
    While on modern compilers uint64_t pointers may be misaligned, it may
    cause problems on older ones.  Moreover, it may lead to slowdown (even
@@ -305,3 +334,18 @@ ensure_eq_size_endian(bitarrayobject *a, bitarrayobject *b)
     }
     return 0;
 }
+
+/* Equivalent to: import bitarray; return getattr(bitarray, name) */
+static inline PyObject *
+bitarray_module_attr(char *name)
+{
+    PyObject *bitarray_module, *result;
+
+    bitarray_module = PyImport_ImportModule("bitarray");
+    if (bitarray_module == NULL)
+        return NULL;
+
+    result = PyObject_GetAttrString(bitarray_module, name);
+    Py_DECREF(bitarray_module);
+    return result;
+}
